tests.reader package — django_dicom 0.1.0 documentation

# tests.reader package

## Submodules

## tests.reader.test_header_information module

class `tests.reader.test_header_information.` `HeaderInformationTestCase`(methodName='runTest')

  Bases: `django.test.testcases.TestCase`

  `KEYWORDS` = {'PatientID': '304848286', 'SOPInstanceUID': '1.3.12.2.1107.5.2.43.66024.2018050112252318571884482', 'SeriesInstanceUID': '1.3.12.2.1107.5.2.43.66024.2018050112250992296484473.0.0.0', 'StudyDate': '20180501', 'StudyInstanceUID': '1.3.12.2.1107.5.2.43.66024.30000018050107081466900000007'}
  `NON_KEYWORDS` = ['ABC', 'DEF', 'GHI', 'JKL']
  `NON_TAGS` = [('1111', '0000'), ('0000', '1111'), ('2222', '3333'), ('3333', '4444')]
  `TAGS` = {('0008', '0060'): 'MR', ('0020', '000D'): '1.3.12.2.1107.5.2.43.66024.30000018050107081466900000007', ('0020', '000E'): '1.3.12.2.1107.5.2.43.66024.2018050112250992296484473.0.0.0', ('0028', '0030'): ['0.48828125', '0.48828125']}
  `setUp`()

    Hook method for setting up the test fixture before exercising it.

  `test_get_element`()
  `test_get_element_by_keyword`()
  `test_get_element_by_keyword_invalid_key_returns_none`()
  `test_get_element_by_tag`()
  `test_get_element_by_tag_invalid_tag_returns_none`()
  `test_get_element_with_invalid_key_or_tag_return_none`()
  `test_get_parsed_value`()
  `test_get_raw_value`()
  `test_get_raw_value_with_invalid_key_returns_none`()
  `test_get_value`()
  `test_get_value_default_configuration`()
  `test_get_value_with_invalid_key_returns_none`()
  `test_initialized_with_default_parser`()

## tests.reader.test_parser module

class `tests.reader.test_parser.` `DicomParserTestCase`(methodName='runTest')

  Bases: `django.test.testcases.TestCase`

  `setUp`()

    Hook method for setting up the test fixture before exercising it.

  `test_parse_age_string`()
  `test_parse_code_string`()
  `test_parse_code_string_with_single_value`()
  `test_parse_code_string_without_enum`()
  `test_parse_date`()
  `test_parse_datetime`()
  `test_parse_decimal_string`()
  `test_parse_decimal_string_with_value_multiplicity`()
  `test_parse_integer_string`()
  `test_parse_siemens_b_matrix`()
  `test_parse_siemens_b_value`()
  `test_parse_siemens_bandwidth_per_pixel_phase_encode`()
  `test_parse_siemens_diffusion_directionality`()
  `test_parse_siemens_gradient_direction`()
  `test_parse_siemens_gradient_mode`()
  `test_parse_siemens_num_images_in_mosaic`()
  `test_parse_siemens_slice_measurement_duration`()
  `test_parse_siemens_slice_timing`()
  `test_parse_time`()
  `test_parse_with_invalid_value_representation`()
  `test_parse_with_keywords`()
  `test_parse_with_tags`()
  `test_parse_with_value_representation_that_has_no_parsing_method`()
  `test_parsing_unknown_element`()

## Module contents